@@ -181,16 +181,15 @@ try:
 
         return RDSEncoder
 
-        def wrap_monkeypatch(fn):
-            @wraps(fn)
-            def wrapper(*args, **kwargs):
-                current_app.json_encoder = get_encoder()
-                return fn(*args, **kwargs)
+    def wrap_monkeypatch(fn):
+        @wraps(fn)
+        def wrapper(*args, **kwargs):
+            current_app.json_encoder = get_json_encoder()
+            return fn(*args, **kwargs)
 
-            return wrapper
-
-        monkeypatch = wrap_monkeypatch(monkeypatch)
+        return wrapper
 
+    monkeypatch = wrap_monkeypatch(monkeypatch)
 
 except:
     pass
